local use = require('packer').use
require('packer').startup(function()
  -- required
  use 'wbthomason/packer.nvim'
  use 'nvim-lua/plenary.nvim'

  -- common/visual plugins
  use 'powerline/powerline-fonts'
  use {
    'nvim-lualine/lualine.nvim',
    requires = { 'kyazdani42/nvim-web-devicons', opt = true }
  }
  use 'kdheepak/tabline.nvim'
  use 'junegunn/goyo.vim'
  use 'gpanders/editorconfig.nvim'
  use {
    'nvim-telescope/telescope-fzf-native.nvim',
    run = 'make'
  }
  use {
    'nvim-telescope/telescope.nvim',
    tag = '0.1.0',
  }
  use {
    'williamboman/mason.nvim',
    'williamboman/mason-lspconfig.nvim',
    'neovim/nvim-lspconfig'
  }
  use 'joshdick/onedark.vim'

  -- syntax highlighting
  use 'posva/vim-vue'
  use 'jwalton512/vim-blade'
end)

require("basics")

function map(mode, shortcut, command)
  vim.keymap.set(mode, shortcut, command, { noremap = true })
end

function nmap(shortcut, command)
  map('n', shortcut, command)
end

local use builtin = require("telescope.builtin")
nmap("<C-P>", builtin.find_files)

require("lualine").setup{
  options = {
    theme = 'onedark'
  }
}

require("tabline").setup{
  vim.cmd([[
    set guioptions-=e
    set sessionoptions+=tabpages,globals
  ]])
}

require("mason").setup()

nmap("<C-T>", "<cmd>TablineTabNew<cr>")
nmap("<C-L>", "<cmd>TablineBufferNext<cr>")
nmap("<C-H>", "<cmd>TablineBufferPrevious<cr>")
nmap("<C-Q>", "<cmd>bd<cr>")
nmap("<C-S-Q>", "<cmd>bd!<cr>")
nmap("<C-B>", "<cmd>ls<cr>")
nmap("<C-G>", "<cmd>Goyo<cr>")
